==> huaweicloudsdkges-3.0.84-py2.py3-none-any.whl: huaweicloudsdkges/v1/model/expand_graph_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ExpandGraphRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'graph_id': 'str',
        'body': 'ExpandGraphReq'
    }

    attribute_map = {
        'graph_id': 'graph_id',
        'body': 'body'
    }

    def __init__(self, graph_id=None, body=None):
        """ExpandGraphRequest - a model defined in huaweicloud sdk"""
        
        

        self._graph_id = None
        self._body = None
        self.discriminator = None

        self.graph_id = graph_id
        if body is not None:
            self.body = body

    @property
    def graph_id(self):
        """Gets the graph_id of this ExpandGraphRequest.

        图ID。

        :return: The graph_id of this ExpandGraphRequest.
        :rtype: str
        """
        return self._graph_id

    @graph_id.setter
    def graph_id(self, graph_id):
        """Sets the graph_id of this ExpandGraphRequest.

        图ID。

        :param graph_id: The graph_id of this ExpandGraphRequest.
        :type: str
        """
        self._graph_id = graph_id

    @property
    def body(self):
        """Gets the body of this ExpandGraphRequest.


        :return: The body of this ExpandGraphRequest.
        :rtype: ExpandGraphReq
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this ExpandGraphRequest.


        :param body: The body of this ExpandGraphRequest.
        :type: ExpandGraphReq
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExpandGraphRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkges-3.0.102-py2.py3-none-any.whl: huaweicloudsdkges/v1/model/expand_graph_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ExpandGraphRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'graph_id': 'str',
        'body': 'ExpandGraphReq'
    }

    attribute_map = {
        'graph_id': 'graph_id',
        'body': 'body'
    }

    def __init__(self, graph_id=None, body=None):
        """ExpandGraphRequest

        The model defined in huaweicloud sdk

        :param graph_id: 图ID。
        :type graph_id: str
        :param body: Body of the ExpandGraphRequest
        :type body: :class:`huaweicloudsdkges.v1.ExpandGraphReq`
        """
        
        

        self._graph_id = None
        self._body = None
        self.discriminator = None

        self.graph_id = graph_id
        if body is not None:
            self.body = body

    @property
    def graph_id(self):
        """Gets the graph_id of this ExpandGraphRequest.

        图ID。

        :return: The graph_id of this ExpandGraphRequest.
        :rtype: str
        """
        return self._graph_id

    @graph_id.setter
    def graph_id(self, graph_id):
        """Sets the graph_id of this ExpandGraphRequest.

        图ID。

        :param graph_id: The graph_id of this ExpandGraphRequest.
        :type graph_id: str
        """
        self._graph_id = graph_id

    @property
    def body(self):
        """Gets the body of this ExpandGraphRequest.


        :return: The body of this ExpandGraphRequest.
        :rtype: :class:`huaweicloudsdkges.v1.ExpandGraphReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this ExpandGraphRequest.


        :param body: The body of this ExpandGraphRequest.
        :type body: :class:`huaweicloudsdkges.v1.ExpandGraphReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExpandGraphRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
